@@ -97,7 +97,7 @@ view_df <- function(x,
                     max.len = 15,
                     sort.by.name = FALSE,
                     wrap.labels = 50,
-                    verbose = TRUE,
+                    verbose = FALSE,
                     CSS = NULL,
                     encoding = NULL,
                     file = NULL,
